@@ -14,7 +14,7 @@ class ModalLink(ColumnBase):
         modal_kwargs = {}
         if row_modify:
             modal_kwargs['row'] = True
-        modal_call = show_modal(modal_name, *modal_args, datatable=True, base64=True , href=True, **modal_kwargs)
+        modal_call = show_modal(modal_name, *modal_args, datatable=True, base64=base64 , href=True, **modal_kwargs)
         css_class = f' class="{css_class}"' if css_class is not None else ""
         link = f'<a href="{modal_call}"{css_class}>{{}}</a>'
 
@@ -28,10 +28,14 @@ class ModalLink(ColumnBase):
                 render_replace(column=f'{self.column_name}:1')
             ]
 
+        if row_modify:
+            self.options['render'].append({'function': 'Row', 'var': '%row%'})
+
 
 class EditColumn(ModalLink):
     def __init__(self, modal_name, button_text='Edit', css_class='btn btn-sm btn-primary', title='',
                  no_col_search=True, **kwargs):
+        button_text = button_text if button_text else modal_buttons['edit']
         super().__init__(modal_name=modal_name, button_text=button_text, title=title, no_col_search=no_col_search,
                          css_class=css_class, **kwargs)
         self.column_defs = {
