@@ -45,8 +45,15 @@ def make_slug(*args, make_pk=False):
     return slug
 
 
+def attr(attributes, tooltip):
+    attributes = {} if attributes is None else attributes
+    if tooltip:
+        attributes.update({'title': tooltip, 'data-tooltip': 'tooltip', 'data-placement': 'top'})
+    return attributes
+
+
 def show_modal(modal_name, *args, base64=False, datatable=False, href=False, button=None,
-               button_classes='btn btn-primary mx-1', row=False, font_awesome=None):
+               button_classes='btn btn-primary mx-1', row=False, font_awesome=None, attributes=None, tooltip=None):
     try:
         javascript = f"django_modal.show_modal('{reverse(modal_name, args=[DUMMY_SLUG])}')"
     except NoReverseMatch:
@@ -59,7 +66,9 @@ def show_modal(modal_name, *args, base64=False, datatable=False, href=False, but
         if base64:
             slug = '%ref%'
         else:
-            if slug:
+            if slug == '-':
+                slug = ''
+            elif slug:
                 slug += '-'
             slug += 'pk-%ref%'
             if row:
@@ -68,9 +77,12 @@ def show_modal(modal_name, *args, base64=False, datatable=False, href=False, but
         javascript = 'javascript:' + javascript
     if button is not None:
         button_text = modal_buttons.get(button, button)
+        attributes = attr(attributes, tooltip)
+        text_attributes = ' ' + ' '.join([f'{k}="{v}"' for k, v in attributes.items()]) if attributes else ''
         if font_awesome:
             button_text = f'<i class="{font_awesome}"></i> {button_text}'
-        javascript = f'<a {css_classes(button_classes)} href="javascript:{javascript}">{button_text}</a>'
+        javascript = (f'<a {css_classes(button_classes)}{text_attributes} '
+                      f'href="javascript:{javascript}">{button_text}</a>')
     if not slug:
         slug = '-'
     return javascript.replace(DUMMY_SLUG, slug)
@@ -96,19 +108,23 @@ def crispy_modal_link(modal_name, text, div=False, div_classes='', button_classe
     return link
 
 
-def modal_button(title, commands, css_class='btn-primary'):
+def modal_button(title, commands, css_class='btn-primary', font_awesome=None):
     if type(commands) == str:
         params = [{'function': commands}]
     elif type(commands) == dict:
         params = [commands]
     else:
         params = commands
+
+    if font_awesome:
+        title = f'<i class="{font_awesome}"></i> {title}'
     return mark_safe(f'''<button onclick='django_modal.process_commands_lock({json.dumps(params)})' 
             class="btn {css_class}" type="button">{title}</button>''')
 
 
-def modal_button_method(title, method_name, css_class='btn-primary', **kwargs):
-    return modal_button(title, dict(function='post_modal', button=dict(button=method_name, **kwargs)), css_class)
+def modal_button_method(title, method_name, css_class='btn-primary', font_awesome=None, **kwargs):
+    return modal_button(title, dict(function='post_modal', button=dict(button=method_name, **kwargs)),
+                        css_class, font_awesome)
 
 
 def modal_button_group(buttons=None, button_container_class=None, button_group_class='btn-group'):
