@@ -2,6 +2,8 @@ import base64
 import binascii
 import json
 import inspect
+
+from ajax_helpers.utils import is_ajax
 from django.forms.fields import Field
 from django.forms.models import modelform_factory, fields_for_model
 from django.http import HttpResponse, JsonResponse
@@ -76,6 +78,7 @@ class BaseModalMixin(AjaxHelpers):
             if not isinstance(base64_data, dict):
                 base64_data = {'base64': base64_data}
             self.slug.update(base64_data)
+            self.kwargs.update(base64_data)
 
     def dispatch(self, request, *args, **kwargs):
         self.split_slug(kwargs)
@@ -99,7 +102,7 @@ class BaseModalMixin(AjaxHelpers):
         return modal_button_group(self.buttons, **button_kwargs)
 
     def check_for_background_page(self, context):
-        if not self.request.is_ajax() and self.modal_mode:
+        if not is_ajax(self.request) and self.modal_mode:
             context['modal_type'] = 'no-parent'
             context['no_header_x'] = True
             context['form'] = render_modal(template_name=self.template_name, **context)
@@ -209,15 +212,15 @@ class FormModalMixin(BaseModalMixin):
             return HttpResponse(str(form))
         return self.refresh_form(form)
 
-    def post_save(self, created):
+    def post_save(self, created, form):
         pass
 
     def form_valid(self, form):
-        org_id = self.object.id if hasattr(self, 'object') else None
+        org_id = self.object.pk if hasattr(self, 'object') else None
         save_function = getattr(form, 'save', None)
         if save_function:
             save_function()
-        self.post_save(created=org_id is None)
+        self.post_save(created=org_id is None, form=form)
         if not self.response_commands:
             self.add_command('reload')
         return self.command_response()
@@ -371,13 +374,18 @@ class ModelFormModal(SingleObjectMixin, FormModal):
     def object_delete(self):
         pass
 
-    def button_confirm_delete(self, **_kwargs):
+    def button_confirm_delete(self, **kwargs):
         if self.process in [processes.PROCESS_DELETE, processes.PROCESS_EDIT_DELETE]:
             self.object.delete()
         self.object_delete()
         if not self.response_commands:
-            self.add_command('close', no_refresh=True)
-            self.add_command('reload')
+            if 'modal_querystring' in kwargs and 'on_delete=' in kwargs['modal_querystring']:
+                self.add_command('redirect', url=base64.urlsafe_b64decode(kwargs['modal_querystring'][
+                                                 kwargs['modal_querystring'].find('on_delete=') + 10:
+                                                 ].split('&')[0]).decode('ascii'))
+            else:
+                self.add_command('close', no_refresh=True)
+                self.add_command('reload')
         return self.command_response()
 
     def button_delete(self, **_kwargs):
@@ -488,13 +496,16 @@ class ModelFormModal(SingleObjectMixin, FormModal):
 
 class MultiForm:
 
-    def __init__(self, model, fields, form_id=None, initial=None, widgets=None, pk=None, **kwargs):
+    def __init__(self, model, fields, form_id=None, initial=None, widgets=None, pk=None, field_classes=None,
+                 labels=None, **kwargs):
         self.model = model
         self.fields = fields
         self.kwargs = kwargs
         self.form_id = form_id
         self.initial = initial if initial else {}
         self.widgets = widgets if widgets else {}
+        self.field_classes = field_classes if field_classes else {}
+        self.labels = labels if labels else {}
         self.pk = pk
 
     def make_form_id(self, used_ids):
@@ -540,7 +551,8 @@ class MultiFormModal(BaseModal):
 
     def get_form_classes(self):
         for f in self.forms:
-            processed_form_fields = ProcessFormFields(f.fields, widgets=f.widgets)
+            processed_form_fields = ProcessFormFields(f.fields, widgets=f.widgets, field_classes=f.field_classes,
+                                                      labels=f.labels)
             self.form_setup_args.append({
                 'form_class': modelform_factory(f.model, form=self.base_form, fields=processed_form_fields.fields,
                                                 **processed_form_fields.extra_kwargs()),
