@@ -53,6 +53,11 @@ if (typeof django_modal == 'undefined') {
         ajax_helpers.command_functions.show_modal = function (command) {
             show_modal(command.modal);
         }
+
+        ajax_helpers.command_functions.show_modal_method = function (command) {
+            ajax_helpers.post_json({ajax_method:command.method, data: command.data, success: create_modal})
+        }
+
         ajax_helpers.command_functions.modal_html = function (command) {
             ajax_helpers.ajax_busy = true
             create_modal(command.html);
@@ -174,7 +179,9 @@ if (typeof django_modal == 'undefined') {
             if (typeof (params) == 'undefined') params = {};
             params.modal_id = active_modal_container_id();
             params.modal_page_url = window.location.pathname;
-            //params.modal_querystring = window.location.search;
+            if (window.location.search !== undefined && window.location.search !==null && window.location.search !==''){
+                params.modal_querystring = window.location.search;
+            }
             return params;
         }
 
@@ -329,10 +336,10 @@ if (typeof django_modal == 'undefined') {
                 $(config.selector).show()
             },
             disable: function (config) {
-                $(config.selector + ' input').attr('disabled', true)
+                $(config.selector).attr('disabled', true)
             },
             enable: function (config) {
-                $(config.selector + ' input').attr('disabled', false)
+                $(config.selector).attr('disabled', false)
             },
             clear: function (config) {
                 $(config.selector + ' input').val('')
